# History

## 1.2.0

* Added type hints
* Added support for python 3.9

## 1.1.0

* Add DRYGlobalPermissionsField

## 1.0.0 (2020-06-10)

* First release on PyPI.
* Forked from https://github.com/dbkaplan/dry-rest-permissions on the same day
* Added support for Django 2.2
* Added support for Django 3.0
* Remove support for all Django version < 2.2
* Added support for Django-Rest-Framework 3.8
* Added support for Django-Rest-Framework 3.9
* Added support for Django-Rest-Framework 3.10
* Added support for Django-Rest-Framework 3.11
* Remove support for all Django-Rest-Framework version < 3.8
* Added support for Python 3.7
* Added support for Python 3.8
* Remove support for Python 2.7